import { TypedEmitter } from 'tiny-typed-emitter';
import { ProductSchema } from '@byondrnd/showroom-schemas';
import { Visualizer } from '../Visualizer';
declare type OnSceneLoaded = (eventData: {
    scene: IScene;
}) => void;
declare type OnVisualizerLoaded = (eventData: {
    visualizer: Visualizer;
}) => void;
declare type OnProductChanged = (eventData: {
    product: ProductSchema.IProduct;
}) => void;
declare type onHotspotClicked = (eventData: {
    application: {
        name: string;
    };
}) => void;
declare type onProductAddedToFavorite = (eventData: {
    favorites: IFavoriteProductList;
    product: IProduct;
}) => void;
declare type onSetAddedToFavorite = (eventData: {
    favoritesSet: IFavoriteSetList;
    set: IFavoriteSet;
}) => void;
declare type onProductRemovedFromFavorite = (eventData: {
    favorites: IFavoriteProductList;
    product: IProduct;
}) => void;
declare type onSetRemovedFromFavorite = (eventData: {
    favoritesSet: IFavoriteSetList;
    set: IFavoriteSet;
}) => void;
declare type onProductAddedToCart = (eventData: {
    product: IProduct;
}) => void;
declare type onOrderSample = (eventData: {
    product: IProduct;
}) => void;
interface IEventSystem {
    /** once, after the visualizer is loaded */
    visualizerLoaded: OnVisualizerLoaded;
    /** every time a scene is loaded */
    sceneLoaded: OnSceneLoaded;
    productChanged: OnProductChanged;
    hotspotClicked: onHotspotClicked;
    productAddedToFavorite: onProductAddedToFavorite;
    setAddedToFavorite: onSetAddedToFavorite;
    productRemovedFromFavorite: onProductRemovedFromFavorite;
    setRemovedFromFavorite: onSetRemovedFromFavorite;
    productAddedToCart: onProductAddedToCart;
    orderSample: onOrderSample;
}
export declare type EventSystemEventSignature = keyof IEventSystem;
export declare type EventSystemEventDataSignature = Parameters<IEventSystem[EventSystemEventSignature]>;
export declare type IScene = {
    id: string;
    index: string;
    title: string;
    image: string;
};
export declare type IFavorite = {
    product: IProduct;
};
export declare type IFavoriteSet = {
    id: string;
    scene: IScene;
    image: string;
    favorites: Array<IFavorite>;
};
export declare type IFavoriteProductList = Array<IFavorite>;
export declare type IFavoriteSetList = Array<IFavoriteSet>;
export declare type IFacet = {
    name: string;
    options: string[];
};
export declare type IFilter = IFacet;
export declare type IProduct = {
    sku: string;
    title: string;
    description: string;
    image: string;
    application: string;
    price: string;
    facets: IFacet[];
};
export interface IVisualizerConfig {
    containerSelector: string;
    experienceId: string;
    sceneId?: string;
}
export declare abstract class EventSystem extends TypedEmitter<IEventSystem> {
    abstract initAndLoad(): any;
    abstract getSceneList(): Array<IScene>;
    abstract GetProductList(application: string, filters?: Array<IFilter>): Array<IProduct>;
    abstract GetApplicationsList(): Array<{
        application: string;
        image: string;
    }>;
    abstract GetFilters(application: string): Array<IFilter>;
    abstract displayProduct(productSku: string, application: string): Promise<void>;
    abstract addProductToFavorite(productSku: string, application: string): IFavoriteProductList;
    abstract removeProductFromFavorite(productSku: string, application: string): IFavoriteProductList;
    abstract getProductFavoriteList(): IFavoriteProductList;
    abstract addSetToFavorite(): Promise<IFavoriteSetList>;
    abstract removeSetFromFavorite(set: IFavoriteSet): IFavoriteSetList;
    abstract getSetFavoriteList(): IFavoriteSetList;
    abstract addProductToCart(product: IProduct): any;
    abstract orderSample(product: IProduct): any;
}
export {};
